==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_hr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hr" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Informacije slike</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Osnovne informacije</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Pojedinosti</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Dodaj u album</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novi album</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Sve slike</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otvori sliku</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Izvezi</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Ukloni iz albuma</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neomiljeni</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Omiljeni</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nemate dozvolu da pogledate sliku</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Vrsta</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Nadnevak izmjene</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Veličina mape</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Način ekspozicije</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program ekspozicije</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Vrijeme ekspozicije</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Bljeskalica</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Žarišna daljina</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Metering mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balans bijele boje</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model leća</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Područje boja</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model kamere</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimenzije</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Natrag</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Prethodno</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Slijedeće</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 veličina</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Pristaje u prozor</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zaokreni u smjeru obrnutom od kazaljke na satu</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zaokreni u smjeru kazaljke na satu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Napusti cijeli zaslon</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Cijeli zaslon</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Ispis</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Klizni prikaz</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Pokaži navigacijski prozor</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Sakrij navigacijski prozor</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Postavi kao tapetu</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži u upravitelju datotekama</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacije slike</translation>
    </message>
    <message>
        <source>day</source>
        <translation>dan</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Potvrdi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Unesi novo ime</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Prethodno</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauziraj</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Next</source>
        <translation>Slijedeće</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Izađi</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>NIje pronađena nijedna slikovna datoteka</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Slikovna datoteka nije nađena</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>Nemate dozvole za gledanje datoteke</translation>
    </message>
</context>
</TS>

==> image-editor_1.0.14.orig.tar.xz: image-editor-1.0.14/libimageviewer/translations/libimageviewer_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Informacije slike</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Osnovne informacije</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Pojedinosti</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Dodaj u album</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Novi album</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Sve slike</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otvori sliku</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Izvezi</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Ukloni iz albuma</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neomiljeni</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Omiljeni</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nemate dozvolu da pogledate sliku</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Vrsta</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Nadnevak izmjene</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Veličina mape</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Način ekspozicije</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program ekspozicije</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Vrijeme ekspozicije</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Bljeskalica</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Žarišna daljina</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balans bijele boje</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model leća</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Područje boja</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model kamere</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimenzije</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Natrag</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Prethodno</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Slijedeće</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 veličina</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Pristaje u prozor</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zaokreni u smjeru obrnutom od kazaljke na satu</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zaokreni u smjeru kazaljke na satu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Napusti cijeli zaslon</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Cijeli zaslon</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Ispis</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Klizni prikaz</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Pokaži navigacijski prozor</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Sakrij navigacijski prozor</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Postavi kao tapetu</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži u upravitelju datotekama</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacije slike</translation>
    </message>
    <message>
        <source>day</source>
        <translation>dan</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Potvrdi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Unesi novo ime</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Prethodno</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauziraj</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Slijedeće</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Izađi</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>NIje pronađena nijedna slikovna datoteka</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Slikovna datoteka nije nađena</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>Nemate dozvole za gledanje datoteke</translation>
    </message>
</context>
</TS>
